# Attention please!

A warning was triggered when creating a new item.

- This may indicate that you are using a plug-in that has been written for an older version of OpenSesame.
- Warnings may trigger bug reports ("Oops, I did it again ..."); you can disable these by disabling the `bug_report` extension.
- Detailed warning information has been printed to the debug window.
